# Terminal CLI for GPT models

## Prerequisites

- Get access to the OpenAI API under: https://openai.com/product

- Once you have access, export your Organization-ID
  (https://platform.openai.com/account/organization) and your API-Key
  (https://platform.openai.com/api-keys) in your shell

  ```bash
  export OPENAI_API_KEY="your_key"
  export OPENAI_ORGANIZATION="your_organization_id"
  ```

## Installation

- Install via pip:
  ```bash
  pip install chatgpterminal
  # start chatting with
  gpt
  ```

## Not yet implemented

- Saving of conversations
- System communication
- conversation saving and management
- Correct messages
- Image Models? (Distant future)
